Double Tap — Kivy v1.0.1-dev documentation

# Double Tap

Search touch for a double tap

class `kivy.input.postproc.doubletap.` `InputPostprocDoubleTap`

  Bases: `object`

  InputPostProcDoubleTap is a post-processor to check if a touch is a double tap or not. Double tap can be configured in the Kivy config file

      [postproc]
          double_tap_time = 250
          double_tap_distance = 20

  Distance parameter is in 0-1000, and time is in millisecond.

  `find_double_tap`(ref)

    Find a double tap touch within self.touches. The touch must be not a previous double tap, and the distance must be ok